==> ro-2.26.zip: ro/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d atașamente';
L10n::$locales['%d comments'] = '%d comentarii';
L10n::$locales['%d trackbacks'] = '%d trackback-uri';
L10n::$locales['%s reactions'] = '';
L10n::$locales['Access to content'] = 'Mergi la conținut';
L10n::$locales['Add a comment'] = 'Adaugă un comentariu';
L10n::$locales['Add ping'] = '';
L10n::$locales['Additionnal style directives'] = '';
L10n::$locales['All keywords'] = 'Toate cuvintele-cheie';
L10n::$locales['Archives'] = 'Arhive';
L10n::$locales['Attachments'] = 'Atașamente';
L10n::$locales['Best of me'] = 'Cel mai bun din mine';
L10n::$locales['Blog info'] = '';
L10n::$locales['Blog menu'] = 'Mergi la meniu';
L10n::$locales['By'] = 'De';
L10n::$locales['By category'] = '';
L10n::$locales['By date'] = '';
L10n::$locales['By tag'] = '';
L10n::$locales['Categories'] = 'Categorii';
L10n::$locales['Comment'] = 'Comentariu';
L10n::$locales['Comments'] = 'Comentarii';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = '';
L10n::$locales['Comments feed'] = 'Abonament de comentarii';
L10n::$locales['Continue reading'] = 'Citește în continuare';
L10n::$locales['Document not found'] = 'Documentul nu a fost găsit';
L10n::$locales['Email address'] = 'Adresă de contact';
L10n::$locales['Email address is not valid'] = 'Adresa de contact nu este valabilă';
L10n::$locales['Entries feed'] = 'Abonament de postări';
L10n::$locales['Explore archives'] = '';
L10n::$locales['Extra menu'] = 'Mergi la meniu';
L10n::$locales['From'] = '';
L10n::$locales['FromDay'] = '';
L10n::$locales['Go to homepage'] = '';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'Codul html este afișat ca text iar adresele web sunt procesate automat.';
L10n::$locales['Home'] = 'Pagină de pornire';
L10n::$locales['In'] = '';
L10n::$locales['Languages'] = 'Limbi';
L10n::$locales['Links'] = 'Legături';
L10n::$locales['Name or nickname'] = 'Nume sau poreclă';
L10n::$locales['Next entry:'] = 'următoarele postări';
L10n::$locales['On'] = 'Activat';
L10n::$locales['Page top'] = '';
L10n::$locales['Pagination'] = '';
L10n::$locales['Password needed'] = 'Parola este necesară';
L10n::$locales['Password:'] = 'Parolă:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Creat de %s';
L10n::$locales['Preview'] = 'previzualizare';
L10n::$locales['Previous entry:'] = 'postări anterioare';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Abonamentul RSS este un sumar de blog gratuit. Oferă conținut (fie postări sau comentarii) sau un sumar de conținut, împreună cu legături web către versiunea completă a conținutului respectiv, și alte metadate. Ultimele conținuturi publicate pot fi citite de către <a href="http://en.wikipedia.org/wiki/Aggregator">abonatorul</a> dvs favorit.';
L10n::$locales['Read'] = 'Citeşte';
L10n::$locales['Remember me on this blog'] = 'Ține-mă minte pe acest blog.';
L10n::$locales['Required field'] = '';
L10n::$locales['Search'] = 'Căutare';
L10n::$locales['Send'] = '';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Pur și simplu copiați următoarea legătură web în abonatorul dvs';
L10n::$locales['Subcategories'] = 'Subcategorii';
L10n::$locales['Subscribe'] = 'Abonare';
L10n::$locales['Subscribe to'] = 'Abonează-te la';
L10n::$locales['Suggestions:'] = '';
L10n::$locales['The document you are looking for does not exist.'] = 'Documentul pe care îl căutați nu există';
L10n::$locales['The list of recents posts is available'] = '';
L10n::$locales['They posted on the same topic'] = 'Și ei au postat pe același subiect';
L10n::$locales['This blog\'s comments Atom feed'] = 'Abonamentul Atom al acestui blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Abonamentul Atom al comentarilor din această categorie';
L10n::$locales['This category\'s entries Atom feed'] = 'Abonamentul Atom al postărilor din această categorie';
L10n::$locales['This post\'s comments Atom feed'] = 'Abonamentul Atom de comentarii al acestei postări';
L10n::$locales['This post\'s comments feed'] = 'Abonamentul comentarilor postării acesteia';
L10n::$locales['To content'] = 'Mergi la conținut';
L10n::$locales['To menu'] = 'Mergi la meniu';
L10n::$locales['To search'] = 'Mergi la căutare';
L10n::$locales['Trackback URL'] = 'Trackback URL';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = '';
L10n::$locales['Use search form'] = '';
L10n::$locales['Website'] = 'Sit web';
L10n::$locales['What is an RSS feed?'] = 'Ce este un abonament RSS?';
L10n::$locales['You must give a password to access this area.'] = 'Trebuie să inserați o parolă pentru a accesa această zonă.';
L10n::$locales['You must provide a comment'] = 'Trebuie să scrii un comentariu';
L10n::$locales['You must provide a valid email address.'] = 'Trebuie să furnizați o adresă email validă.';
L10n::$locales['You must provide an author name'] = 'Trebuie să specifici un nume de autor';
L10n::$locales['Your comment'] = 'Comentariul dvs';
L10n::$locales['Your comment has been published.'] = 'Comentariul dvs a fost publicat.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Comentariul dvs a fost trimis și va fi revizuit înainte de publicare.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Căutate dvs după <em>%1$s</em> are următorul <strong>%2$s</strong> rezultat';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Căutate dvs după <em>%1$s</em> are următoarele <strong>%2$s</strong> rezultate';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Căutarea dvs după <em>%1$s</em> nu are rezultate.';
L10n::$locales['by'] = 'de';
L10n::$locales['here'] = '';
L10n::$locales['in'] = '';
L10n::$locales['next entries'] = 'următoarele postări';
L10n::$locales['no attachments'] = 'niciun atașament';
L10n::$locales['no comments'] = 'niciun comentariu';
L10n::$locales['no reactions'] = '';
L10n::$locales['no trackbacks'] = 'fără trackback';
L10n::$locales['of'] = 'de';
L10n::$locales['on'] = 'activat';
L10n::$locales['one attachment'] = 'un atașament';
L10n::$locales['one comment'] = 'un comentariu';
L10n::$locales['one reaction'] = 'Citește în continuare';
L10n::$locales['one trackback'] = 'un trackback';
L10n::$locales['optional'] = 'opțional';
L10n::$locales['page'] = 'pagină';
L10n::$locales['preview'] = 'previzualizare';
L10n::$locales['previous entries'] = 'postări anterioare';
L10n::$locales['reactions'] = '';
L10n::$locales['send'] = 'trimite';
L10n::$locales['toDay'] = '';

==> ro-2.27.3.zip: ro/public.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright GPL-2.0-only
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%d attachments'] = '%d atașamente';
L10n::$locales['%d comments'] = '%d comentarii';
L10n::$locales['%d trackbacks'] = '%d trackback-uri';
L10n::$locales['%s reactions'] = '%s reacții';
L10n::$locales['Access to content'] = 'Accesul la conținut';
L10n::$locales['Add a comment'] = 'Adaugă un comentariu';
L10n::$locales['Add ping'] = 'Adaugă ping-ul';
L10n::$locales['Additionnal style directives'] = 'Alte directive de tip adiţional';
L10n::$locales['All keywords'] = 'Toate cuvintele-cheie';
L10n::$locales['Archives'] = 'Arhive';
L10n::$locales['Attachments'] = 'Atașamente';
L10n::$locales['Best of me'] = 'Cel mai bun din mine';
L10n::$locales['Blog info'] = 'Informații blog';
L10n::$locales['Blog menu'] = 'Meniu blog';
L10n::$locales['By'] = 'De';
L10n::$locales['By category'] = 'După categorie';
L10n::$locales['By date'] = 'După dată';
L10n::$locales['By tag'] = 'După etichetă';
L10n::$locales['Categories'] = 'Categorii';
L10n::$locales['Comment'] = 'Comentariu';
L10n::$locales['Comments'] = 'Comentarii';
L10n::$locales['Comments can be formatted using a simple wiki syntax.'] = 'Comentariile pot fi formatate folosind o sintaxă wiki simplă.';
L10n::$locales['Comments feed'] = 'Abonament de comentarii';
L10n::$locales['Continue reading'] = 'Citește în continuare';
L10n::$locales['Document not found'] = 'Documentul nu a fost găsit';
L10n::$locales['Email address'] = 'Adresă de contact';
L10n::$locales['Email address is not valid'] = 'Adresa de contact nu este valabilă';
L10n::$locales['Entries feed'] = 'Abonament de postări';
L10n::$locales['Explore archives'] = 'Explorează arhive';
L10n::$locales['Extra menu'] = 'Extra menu';
L10n::$locales['From'] = 'De la';
L10n::$locales['FromDay'] = 'Zile';
L10n::$locales['Go to homepage'] = 'Du-te la pagina principală';
L10n::$locales['HTML code is displayed as text and web addresses are automatically converted.'] = 'Codul html este afișat ca text iar adresele web sunt procesate automat.';
L10n::$locales['Home'] = 'Pagină de pornire';
L10n::$locales['In'] = 'În';
L10n::$locales['Languages'] = 'Limbi';
L10n::$locales['Links'] = 'Legături';
L10n::$locales['Name or nickname'] = 'Nume sau poreclă';
L10n::$locales['Next entry:'] = 'Următoarea intrare:';
L10n::$locales['On'] = 'Activat';
L10n::$locales['Page top'] = 'Pagina de sus';
L10n::$locales['Pagination'] = 'Paginare';
L10n::$locales['Password needed'] = 'Parola este necesară';
L10n::$locales['Password:'] = 'Parolă:';
L10n::$locales['Permalink'] = 'Permalink';
L10n::$locales['Powered by %s'] = 'Creat de %s';
L10n::$locales['Preview'] = 'Previzualizare';
L10n::$locales['Previous entry:'] = 'Intrare anterioară:';
L10n::$locales['RSS feed is a free blog summary. It provides content (either posts or comments) or summaries of content, together with links to the full versions, and other metadata. The last published items may then be read by your favorite RSS <a href="http://en.wikipedia.org/wiki/Aggregator">aggregator</a>.'] = 'Abonamentul RSS este un sumar de blog gratuit. Oferă conținut (fie postări sau comentarii) sau un sumar de conținut, împreună cu legături web către versiunea completă a conținutului respectiv, și alte metadate. Ultimele conținuturi publicate pot fi citite de către <a href="http://en.wikipedia.org/wiki/Aggregator">abonatorul</a> dvs favorit.';
L10n::$locales['Read'] = 'Citeşte';
L10n::$locales['Remember me on this blog'] = 'Ține-mă minte pe acest blog.';
L10n::$locales['Required field'] = 'Câmp obligatoriu';
L10n::$locales['Search'] = 'Căutare';
L10n::$locales['Send'] = 'Trimite';
L10n::$locales['Simply copy the following URL into your aggregator:'] = 'Pur și simplu copiați următoarea legătură web în abonatorul dvs';
L10n::$locales['Subcategories'] = 'Subcategorii';
L10n::$locales['Subscribe'] = 'Abonare';
L10n::$locales['Subscribe to'] = 'Abonează-te la';
L10n::$locales['Suggestions:'] = 'Sugestii:';
L10n::$locales['The document you are looking for does not exist.'] = 'Documentul pe care îl căutați nu există';
L10n::$locales['The list of recents posts is available'] = 'Lista postărilor recente este disponibilă';
L10n::$locales['They posted on the same topic'] = 'Și ei au postat pe același subiect';
L10n::$locales['This blog\'s comments Atom feed'] = 'Abonamentul Atom al acestui blog';
L10n::$locales['This category\'s comments Atom feed'] = 'Abonamentul Atom al comentarilor din această categorie';
L10n::$locales['This category\'s entries Atom feed'] = 'Abonamentul Atom al postărilor din această categorie';
L10n::$locales['This post\'s comments Atom feed'] = 'Abonamentul Atom de comentarii al acestei postări';
L10n::$locales['This post\'s comments feed'] = 'Abonamentul comentarilor postării acesteia';
L10n::$locales['To content'] = 'Mergi la conținut';
L10n::$locales['To menu'] = 'Mergi la meniu';
L10n::$locales['To search'] = 'Mergi la căutare';
L10n::$locales['Trackback URL'] = 'URL Trackback';
L10n::$locales['URL you\'ve tried has typos, or the page has been deleted or moved.'] = 'URL-ul pe care l-ați încercat are typos, sau pagina a fost ștearsă sau mutată.';
L10n::$locales['Use search form'] = 'Folosește formularul de căutare';
L10n::$locales['Website'] = 'Sit web';
L10n::$locales['What is an RSS feed?'] = 'Ce este un abonament RSS?';
L10n::$locales['You must give a password to access this area.'] = 'Trebuie să inserați o parolă pentru a accesa această zonă.';
L10n::$locales['You must provide a comment'] = 'Trebuie să scrii un comentariu';
L10n::$locales['You must provide a valid email address.'] = 'Trebuie să furnizați o adresă email validă.';
L10n::$locales['You must provide an author name'] = 'Trebuie să specifici un nume de autor';
L10n::$locales['Your comment'] = 'Comentariul dvs';
L10n::$locales['Your comment has been published.'] = 'Comentariul dvs a fost publicat.';
L10n::$locales['Your comment has been submitted and will be reviewed for publication.'] = 'Comentariul dvs a fost trimis și va fi revizuit înainte de publicare.';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> result.'] = 'Căutate dvs după <em>%1$s</em> are următorul <strong>%2$s</strong> rezultat';
L10n::$locales['Your search for <em>%1$s</em> returned <strong>%2$s</strong> results.'] = 'Căutate dvs după <em>%1$s</em> are următoarele <strong>%2$s</strong> rezultate';
L10n::$locales['Your search for <em>%1$s</em> returned no result.'] = 'Căutarea dvs după <em>%1$s</em> nu are rezultate.';
L10n::$locales['by'] = 'de';
L10n::$locales['here'] = 'aici';
L10n::$locales['in'] = 'în';
L10n::$locales['next entries'] = 'următoarele postări';
L10n::$locales['no attachments'] = 'niciun atașament';
L10n::$locales['no comments'] = 'fără comentarii';
L10n::$locales['no reactions'] = 'fără reacţii';
L10n::$locales['no trackbacks'] = 'fără trackback';
L10n::$locales['of'] = 'de';
L10n::$locales['on'] = 'activat';
L10n::$locales['one attachment'] = 'un atașament';
L10n::$locales['one comment'] = 'un comentariu';
L10n::$locales['one reaction'] = 'o reacţie';
L10n::$locales['one trackback'] = 'un trackback';
L10n::$locales['optional'] = 'opțional';
L10n::$locales['page'] = 'pagină';
L10n::$locales['preview'] = 'previzualizare';
L10n::$locales['previous entries'] = 'postări anterioare';
L10n::$locales['reactions'] = 'reacţii';
L10n::$locales['send'] = 'trimite';
L10n::$locales['toDay'] = 'până la';
